@@ -13,8 +13,8 @@
 package Directory::Queue::Normal;
 use strict;
 use warnings;
-our $VERSION  = "2.0";
-our $REVISION = sprintf("%d.%02d", q$Revision: 1.14 $ =~ /(\d+)\.(\d+)/);
+our $VERSION  = "2.1";
+our $REVISION = sprintf("%d.%02d", q$Revision: 1.15 $ =~ /(\d+)\.(\d+)/);
 
 #
 # used modules
@@ -694,7 +694,7 @@ sub purge : method {
 
     # check options
     $option{maxtemp} = $self->{maxtemp} unless defined($option{maxtemp});
-    $option{maxlock} = $self->{maxtemp} unless defined($option{maxlock});
+    $option{maxlock} = $self->{maxlock} unless defined($option{maxlock});
     foreach my $name (keys(%option)) {
         dief("unexpected option: %s", $name)
             unless $name =~ /^(maxtemp|maxlock)$/;
@@ -1042,4 +1042,4 @@ L<Directory::Queue>.
 
 Lionel Cons L<http://cern.ch/lionel.cons>
 
-Copyright (C) CERN 2010-2018
+Copyright (C) CERN 2010-2021
